export declare abstract class Base {
    private baseUrl;
    protected apiKey: string;
    protected merchantCode: string;
    protected consumerSecret: string;
    protected env?: string;
    protected privateKeyPath: string;
    protected enableLogging?: boolean;
    protected enableAuthorization?: boolean;
    private token;
    private verbose?;
    constructor(config: Config);
    protected request<T>(endpoint: string, options?: RequestInit | Options, parameters?: {}): Promise<T>;
    protected withAuth<T>(config: any, url: any, parameters?: {}): Promise<T>;
    protected updateConfigs<T>(config: {
        apiKey?: string;
        merchantCode?: string;
        consumerSecret?: string;
        env?: string;
        privateKeyPath?: string;
        enableLogging?: boolean;
        enableAuthorization?: boolean;
        verbose?: boolean;
    }, callback?: Function | null): Promise<T> | void;
    generateToken<AuthResponse>(): Promise<AuthResponse>;
    updateConfig(config: UpdateConfig, callback?: Function): {
        apiKey: string;
        merchantCode: string;
        consumerSecret: string;
        env: string;
        verbose: boolean;
        privateKeyPath: string;
        enableLogging: boolean;
        enableAuthorization: boolean;
    };
    getConfig(): {
        apiKey: string;
        merchantCode: string;
        consumerSecret: string;
        env: string;
        verbose: boolean;
        privateKeyPath: string;
        enableLogging: boolean;
        enableAuthorization: boolean;
    };
}
type Config = {
    apiKey: string;
    merchantCode: string;
    consumerSecret: string;
    privateKeyPath: string;
    env?: string;
    enableLogging?: boolean;
    enableAuthorization?: boolean;
    verbose?: boolean;
};
type Options = {
    headers?: any;
    data?: any;
    params?: any;
};
type UpdateConfig = {
    apiKey?: string;
    merchantCode?: string;
    consumerSecret?: string;
    env?: string;
    privateKeyPath?: string;
    enableLogging?: boolean;
    enableAuthorization?: boolean;
    verbose?: boolean;
};
export declare interface AuthResponse {
    accessToken: string;
    refreshToken?: string;
    expiresIn?: string;
    issuedAt?: string;
    tokenType?: string;
}
export {};
